@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "tree-sitter" "0.19.4"
+(define-package "tree-sitter" "20251222.1802"
   "Incremental parsing system."
   '((emacs "27.1")
-    (tsc   "0.19.4"))
+    (tsc   "0.19.3"))
   :url "https://github.com/emacs-tree-sitter/elisp-tree-sitter"
-  :commit "8f0bd387ad7a1cf7e8fdd5977d386a17ea70a82d"
-  :revdesc "8f0bd387ad7a"
+  :commit "d12aff8ee91dcd643da0a65a3bcee7be9a3cac68"
+  :revdesc "d12aff8ee91d"
   :keywords '("languages" "tools" "parsers" "tree-sitter")
   :authors '(("Tuấn-Anh Nguyễn" . "ubolonton@gmail.com"))
   :maintainers '(("Jen-Chieh Shen" . "jcs090218@gmail.com")))
